@@ -55,6 +55,7 @@ def parse_arguments(defaults):
     _option_group_general.add_argument("--overwrite", action="store_true", help="Allow overwrite files in-place. Default is skip and warn. NOTE: output fils are always overwritten. (Dangerous!!)", default=defaults.get("overwrite"))
     _option_group_general.add_argument("--on-change", action="store_true", help="Allow overwrite files only on source changed (detected by modify time).", default=defaults.get("on_change"))
     _option_group_general.add_argument("--verbose", action="store_true", help="Show output during processing.", default=defaults.get("verbose"))
+    _option_group_general.add_argument("--force", action="store_true", help="Overwrite even if destination exists and is newer.", default=defaults.get("force"))
     _option_group_general.add_argument("--zipy", action="store_true", help="GZIP Processed files as '*.gz'.", default=defaults.get("zipy"))
 
     _option_group_general.add_argument("--disable-js", action="store_true", dest="disable_js", default=False, help="Copy .js files verbatim instead of processing")
@@ -124,7 +125,7 @@ def main():
     """
     Commandline entrypoint
     """
-    defaults = {"format": "", "overwrite": False, "on_change": True, "verbose": False, "zipy": False, "sort": False, "comments": False, "timestamp": False, "wrap": False, "input": "", "output": ""}
+    defaults = {"format": "", "overwrite": False, "on_change": True, "verbose": False, "force": False, "zipy": False, "sort": False, "comments": False, "timestamp": False, "wrap": False, "input": "", "output": ""}
     args = vars(parse_arguments(defaults))
     settings = {**defaults, **args}
     verbose = settings.get("verbose", False)
